#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['drf_info_endpoint']

package_data = \
{'': ['*']}

install_requires = \
['drf-spectacular>=0.17.2', 'django>=3.2', 'djangorestframework>=3.10.0']

setup(name='drf_info_endpoint',
      version='0.0.1',
      description='Django Rest Framework Project Info View',
      author='Viacheslav Krachkov',
      author_email='vskrachkov@gmail.com',
      url='https://github.com/vskrachkov/drf_info_endpoint',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.9',
     )
